@@ -1,4 +1,4 @@
-## This program is free software; you can redistribute it and/or modify
+﻿## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published
 ## by the Free Software Foundation; version 2 or any later version.
 ##
@@ -35,7 +35,7 @@ class ListDialog(hildon.Dialog):
     self.action_area.pack_end(del_btn)
     self.action_area.pack_end(ok_btn)
     self.show_all()
-    
+
   def _do_del(self, e):
     d = self.selector.get_current_text()
     note = hildon.hildon_note_new_confirmation(self, \
@@ -55,20 +55,23 @@ class ListDialog(hildon.Dialog):
 
   def _get_dirlist(self):
     return [r[0] for r in self.selector.get_model(0)]
-    
+
   the_list = property(_get_dirlist)
 
 class DirListDialog(ListDialog):
 
   def __init__(self, parent, title, strlist):
     ListDialog.__init__(self, parent, title, strlist)
-    
+
   def _do_add(self, e):
     fcd = gobject.new(hildon.FileChooserDialog, action=gtk.FILE_CHOOSER_ACTION_SELECT_FOLDER)
     fcd.set_title('Select directory')
     r = fcd.run()
     if r==gtk.RESPONSE_OK:
-      self.selector.append_text(fcd.get_filename())
+      dirname = fcd.get_filename()
+      if not dirname[-1]=='/':
+        dirname += '/'
+      self.selector.append_text(dirname)
     fcd.destroy()
 
 class TextEntryDialog(gtk.Dialog):
@@ -80,16 +83,15 @@ class TextEntryDialog(gtk.Dialog):
     self.entry.set_placeholder(pht)
     self.vbox.pack_start(self.entry)
     self.show_all()
-    
+
 class StrListDialog(ListDialog):
   def __init__(self, parent, title, strlist):
     ListDialog.__init__(self, parent, title, strlist)
-    
+
   def _do_add(self, e):
     ted = TextEntryDialog(self, 'Add new entry')
     r = ted.run()
     if r==gtk.RESPONSE_OK:
       self.selector.append_text(ted.entry.get_text())
     ted.destroy()
-    
-  
+
