@@ -1,4 +1,4 @@
-## This program is free software; you can redistribute it and/or modify
+﻿## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published
 ## by the Free Software Foundation; version 2 or any later version.
 ##
@@ -90,4 +90,4 @@ contents = (\
   ('MinBucketCount', 'textentry', '32768'),
   ('MaxBucketCount', 'textentry', '65535'),
 ))
-)
+)
\ No newline at end of file
